@@ -63,7 +63,7 @@ async def get(
 
 
 async def list_(
-    hub, ctx, crypto_key: str, filter: str = None, order_by: str = None
+    hub, ctx, crypto_key: str, filter_: str = None, order_by: str = None
 ) -> Dict[str, Any]:
     r"""Retrieves the crypto key versions in a crypto key.
 
@@ -71,7 +71,7 @@ async def list_(
         crypto_key(str):
             key ring resource_id.
 
-        filter(str, Optional):
+        filter_(str, Optional):
             Only include resources that match the filter in the response. For more information, see
             `Sorting and filtering list results`_.
 
@@ -89,7 +89,7 @@ async def list_(
                    - path: gcp.cloudkms.crypto_key_version.list
                    - kwargs:
                          crypto_key: projects/project-name/locations/global/keyRings/kr-global-test
-                         filter: algorithm = GOOGLE_SYMMETRIC_ENCRYPTION
+                         filter_: algorithm = GOOGLE_SYMMETRIC_ENCRYPTION
     """
     result = {
         "comment": [],
@@ -98,7 +98,7 @@ async def list_(
     }
 
     crypto_key_versions = await hub.exec.gcp_api.client.cloudkms.projects.locations.key_rings.crypto_keys.crypto_key_versions.list(
-        ctx, parent=crypto_key, filter=filter, orderBy=order_by
+        ctx, parent=crypto_key, filter=filter_, orderBy=order_by
     )
     if not crypto_key_versions["result"]:
         result["comment"] += crypto_key_versions["comment"]
