@@ -7,6 +7,11 @@ from typing import List
 
 from dict_tools.typing import Computed
 
+from idem_gcp.tool.gcp.utils import zonal_absent
+
+# prevent commit hook from removing the import
+absent = zonal_absent
+
 __contracts__ = ["resource"]
 
 
@@ -636,10 +641,9 @@ async def present(
                 )
                 return result
         else:
+            result["new_state"] = result["old_state"]
             result["comment"].append(
-                hub.tool.gcp.comment_utils.already_exists_comment(
-                    "gcp.compute.disk", name
-                )
+                hub.tool.gcp.comment_utils.up_to_date_comment("gcp.compute.disk", name)
             )
     else:
         if ctx["test"]:
@@ -688,40 +692,6 @@ async def present(
     return result
 
 
-async def absent(
-    hub,
-    ctx,
-    name: str = None,
-    project: str = None,
-    resource_id: str = None,
-    zone: str = None,
-    request_id: str = None,
-) -> Dict[str, Any]:
-    r"""Deletes the resource.
-
-    Args:
-        name(str, Optional):
-            An Idem name of the resource.
-
-        project(str, Optional):
-            Project ID for this request.
-
-        request_id(str, Optional):
-            An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000). Defaults to None.
-
-        resource_id(str, Optional):
-            An identifier of the resource in the provider. Defaults to None.
-
-        zone(str, Optional):
-            The name of the zone for this request.
-
-    Returns:
-        Dict[str, Any]
-    """
-    # the method is handled via the recursive_contracts->call_absent
-    raise NotImplementedError
-
-
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
     r"""Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
