@@ -4,15 +4,21 @@ Copyright (c) 2022 VMware, Inc. All Rights Reserved.
 SPDX-License-Identifier: Apache-2.0
 
 """
-
-__contracts__ = ["resource"]
-
 from dataclasses import field
 from dataclasses import make_dataclass
+from typing import Any
+from typing import Dict
+from typing import List
+
 from dict_tools.typing import Computed
-from typing import Dict, Any, List
 
 from idem_gcp.tool.gcp.state_operation_utils import StateOperations
+from idem_gcp.tool.gcp.utils import zonal_absent
+
+# prevent commit hook from removing the import
+absent = zonal_absent
+
+__contracts__ = ["resource"]
 
 
 async def present(
@@ -1273,28 +1279,32 @@ async def present(
 
         state_operations_ret = await state_operations.run_operations()
 
+        current_state = result["old_state"]
+        if "new_state" in state_operations_ret:
+            current_state = state_operations_ret["new_state"]
+        elif any(state_operations.changed_properties_dict.values()):
+            get_ret = await hub.exec.gcp.compute.instance.get(
+                ctx, resource_id=resource_id
+            )
+            if not get_ret["result"] or not get_ret["ret"]:
+                result["result"] = False
+                result["comment"] += get_ret["comment"]
+                return result
+            current_state = get_ret["ret"]
+        result["new_state"] = current_state
+
         if not state_operations_ret["result"]:
             result["comment"] += state_operations_ret["comment"]
             result["result"] = False
             return result
-        elif "new_state" in state_operations_ret:
-            result["new_state"] = state_operations_ret["new_state"]
 
         if changes:
             if any(state_operations.changed_properties_dict.values()):
-                get_ret = await hub.exec.gcp.compute.instance.get(
-                    ctx, resource_id=resource_id
-                )
-                if not get_ret["result"] and not get_ret["ret"]:
-                    result["result"] = False
-                    result["comment"] += get_ret["comment"]
-                    return result
-
                 for k in patch_operations_dict.keys():
-                    resource_body[k] = get_ret["ret"].get(k)
+                    resource_body[k] = current_state.get(k)
 
-                resource_body["fingerprint"] = get_ret["ret"].get("fingerprint")
-                resource_body["label_fingerprint"] = get_ret["ret"].get(
+                resource_body["fingerprint"] = current_state.get("fingerprint")
+                resource_body["label_fingerprint"] = current_state.get(
                     "label_fingerprint"
                 )
 
@@ -1389,40 +1399,6 @@ async def present(
     return result
 
 
-async def absent(
-    hub,
-    ctx,
-    name: str = None,
-    zone: str = None,
-    project: str = None,
-    resource_id: str = None,
-    request_id: str = None,
-) -> Dict[str, Any]:
-    r"""Deletes the resource.
-
-    Args:
-        name(str, Optional):
-            An Idem name of the resource.
-
-        zone:(str, Optional):
-            The name of the zone for this request.
-
-        project(str):
-            Project ID for this request.
-
-        request_id(str, Optional):
-            An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000). Defaults to None.
-
-        resource_id(str, Optional):
-            An identifier of the resource in the provider. Defaults to None.
-
-    Returns:
-        Dict[str, Any]
-    """
-    # the method is handled via the recursive_contracts->call_absent
-    raise NotImplementedError
-
-
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
     r"""Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
