@@ -7,6 +7,11 @@ from typing import List
 
 from dict_tools.typing import Computed
 
+from idem_gcp.tool.gcp.utils import global_absent
+
+# prevent commit hook from removing the import
+absent = global_absent
+
 __contracts__ = ["resource"]
 
 
@@ -163,18 +168,61 @@ async def present(
 
         resource_id = handle_operation_ret["resource_id"]
 
+    get_resource_only_with_resource_id = hub.OPT.idem.get(
+        "get_resource_only_with_resource_id", False
+    )
     if resource_id:
         old_get_ret = await hub.exec.gcp.compute.network.get(
             ctx, resource_id=resource_id
         )
 
-        if not old_get_ret["result"] or not old_get_ret["ret"]:
+        if not old_get_ret["result"] or (
+            not old_get_ret["ret"] and get_resource_only_with_resource_id
+        ):
             result["result"] = False
             result["comment"] += old_get_ret["comment"]
             return result
 
+        # long running operation has succeeded - both update and create
+        if ctx.get("rerun_data"):
+            result["new_state"] = old_get_ret["ret"]
+            result["old_state"] = ctx["rerun_data"]["old_state"]
+            if ctx["rerun_data"]["old_state"]:
+                result["comment"].append(
+                    hub.tool.gcp.comment_utils.update_comment(
+                        "gcp.compute.network", name
+                    )
+                )
+            else:
+                result["comment"].append(
+                    hub.tool.gcp.comment_utils.create_comment(
+                        "gcp.compute.network", name
+                    )
+                )
+                # Handle the peerings addition when new network is created
+                if not result["new_state"].get("peerings") and peerings:
+                    add_peerings_ret = await hub.tool.gcp.compute.network.add_peerings(
+                        ctx, resource_id, peerings
+                    )
+                    if not add_peerings_ret["result"]:
+                        result["result"] = False
+                        result["comment"] += add_peerings_ret["comment"]
+                        return result
+
+                # Make a new get request containing the peerings in their form in gcp api
+                get_ret = await hub.exec.gcp_api.client.compute.network.get(
+                    ctx, name=name, resource_id=resource_id
+                )
+                if not get_ret["result"] and not get_ret["ret"]:
+                    result["result"] = False
+                    result["comment"] += get_ret["comment"]
+                    return result
+                result["new_state"] = get_ret["ret"]
+
+            return result
+
         result["old_state"] = old_get_ret["ret"]
-    elif not hub.OPT.idem.get("get_resource_only_with_resource_id", False):
+    elif not get_resource_only_with_resource_id:
         resource_id = (ctx.get("old_state") or {}).get(
             "resource_id"
         ) or hub.tool.gcp.resource_prop_utils.construct_resource_id(
@@ -208,22 +256,29 @@ async def present(
     request_body = {k: v for (k, v) in request_body.items() if v is not None}
     operation = None
     if result["old_state"]:
-        new_state_for_whole_resource_comparison = {
-            "resource_id": resource_id,
-            **request_body,
-        }
-        if result["old_state"].get("peerings"):
-            new_state_for_whole_resource_comparison["peerings"] = result[
-                "old_state"
-            ].get("peerings")
-        else:
-            new_state_for_whole_resource_comparison.pop("peerings", None)
-
         changes = hub.tool.gcp.utils.compare_states(
             result["old_state"],
-            new_state_for_whole_resource_comparison,
+            request_body,
             "compute.network",
         )
+        if changes:
+            changed_non_updatable_properties = (
+                hub.tool.gcp.resource_prop_utils.get_changed_non_updatable_properties(
+                    "compute.network", changes
+                )
+            )
+            if changed_non_updatable_properties:
+                result["result"] = False
+                result["comment"].append(
+                    hub.tool.gcp.comment_utils.non_updatable_properties_comment(
+                        "gcp.compute.network",
+                        name,
+                        changed_non_updatable_properties,
+                    )
+                )
+                result["new_state"] = result["old_state"]
+                return result
+
         are_peerings_changed = (
             not hub.tool.gcp.state_comparison_utils.are_lists_identical(
                 result["old_state"].get("peerings"), peerings
@@ -233,11 +288,11 @@ async def present(
         if not changes and not are_peerings_changed:
             result["result"] = True
             result["comment"].append(
-                hub.tool.gcp.comment_utils.already_exists_comment(
+                hub.tool.gcp.comment_utils.up_to_date_comment(
                     "gcp.compute.network", name
                 )
             )
-            result["new_state"] = result["old_state"]
+            result["new_state"] = {"resource_id": resource_id, **request_body}
             return result
 
         if ctx["test"]:
@@ -246,8 +301,7 @@ async def present(
                     "gcp.compute.network", name
                 )
             )
-            result["new_state"] = request_body
-            result["new_state"]["resource_id"] = resource_id
+            result["new_state"] = {"resource_id": resource_id, **request_body}
             return result
 
         if are_peerings_changed:
@@ -284,6 +338,13 @@ async def present(
                 if hub.tool.gcp.operation_utils.is_operation(patch_ret["ret"]):
                     operation = patch_ret["ret"]
 
+        get_ret = await hub.exec.gcp.compute.network.get(ctx, resource_id=resource_id)
+        if not get_ret["result"] and not get_ret["ret"]:
+            result["result"] = False
+            result["comment"] += get_ret["comment"]
+            return result
+
+        result["new_state"] = get_ret["ret"]
         result["comment"].append(
             hub.tool.gcp.comment_utils.update_comment("gcp.compute.network", name)
         )
@@ -294,109 +355,47 @@ async def present(
                     "gcp.compute.network", name
                 )
             )
-            result["new_state"] = request_body
-            result["new_state"]["resource_id"] = resource_id
+            result["new_state"] = {"resource_id": resource_id, **request_body}
             return result
 
-        # Create
         create_ret = await hub.exec.gcp_api.client.compute.network.insert(
             ctx, name=name, project=project, body=request_body
         )
-        if not create_ret["result"]:
+        if not create_ret["result"] or not create_ret["ret"]:
             result["result"] = False
-            result["comment"] += create_ret["comment"]
+            if create_ret["comment"] and next(
+                (
+                    comment
+                    for comment in create_ret["comment"]
+                    if "alreadyExists" in comment
+                ),
+                None,
+            ):
+                result["comment"].append(
+                    hub.tool.gcp.comment_utils.already_exists_comment(
+                        "gcp.compute.network", name
+                    )
+                )
+            else:
+                result["comment"] += create_ret["comment"]
             return result
 
-        result["old_state"] = {}
-        resource_id = create_ret["ret"].get("resource_id")
-        if hub.tool.gcp.operation_utils.is_operation(create_ret["ret"]):
+        if hub.tool.gcp.operation_utils.is_operation(create_ret.get("ret")):
             operation = create_ret["ret"]
 
     if operation:
         operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
             operation.get("selfLink"), "compute.global_operation"
         )
-        handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, {"operation_id": operation_id}, "compute.network"
-        )
-
-        if not handle_operation_ret["result"]:
-            result["comment"] += handle_operation_ret["comment"]
-            if handle_operation_ret.get("rerun_data"):
-                result["rerun_data"] = handle_operation_ret["rerun_data"]
-                if handle_operation_ret["rerun_data"].get("has_error", False):
-                    result["result"] = False
-            else:
-                result["result"] = False
-
-            return result
-
-        resource_id = handle_operation_ret["resource_id"]
-
-    # Try getting the resource again
-    # TODO: Reconciliation or waiter loop?
-    # TODO: Check if this can be removed because insert and update may also return the necessary data on success
-    get_ret = await hub.exec.gcp_api.client.compute.network.get(
-        ctx, name=name, resource_id=resource_id
-    )
-    if not get_ret["result"] and not get_ret["ret"]:
+        result["rerun_data"] = {
+            "operation_id": operation_id,
+            "old_state": result["old_state"],
+        }
         result["result"] = False
-        result["comment"] += get_ret["comment"]
-        return result
-    result["new_state"] = get_ret["ret"]
 
-    # Handle the peerings addition when new network is created
-    if not result["new_state"].get("peerings") and peerings:
-        add_peerings_ret = await hub.tool.gcp.compute.network.add_peerings(
-            ctx, resource_id, peerings
-        )
-        if not add_peerings_ret["result"]:
-            result["result"] = False
-            result["comment"] += add_peerings_ret["comment"]
-            return result
-
-    # Make a new get request containing the peerings in their form in gcp api
-    get_ret = await hub.exec.gcp_api.client.compute.network.get(
-        ctx, name=name, resource_id=resource_id
-    )
-    if not get_ret["result"] and not get_ret["ret"]:
-        result["result"] = False
-        result["comment"] += get_ret["comment"]
-        return result
-    result["new_state"] = get_ret["ret"]
     return result
 
 
-async def absent(
-    hub,
-    ctx,
-    name: str = None,
-    project: str = None,
-    resource_id: str = None,
-    request_id: str = None,
-) -> Dict[str, Any]:
-    r"""Deletes the resource.
-
-    Args:
-        name(str, Optional):
-            An Idem name of the resource.
-
-        project(str, Optional):
-            Project ID for this request.
-
-        request_id(str, Optional):
-            An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000). Defaults to None.
-
-        resource_id(str, Optional):
-            An identifier of the resource in the provider. Defaults to None.
-
-    Returns:
-        Dict[str, Any]
-    """
-    # the method is handled via the recursive_contracts->call_absent
-    raise NotImplementedError
-
-
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
     r"""Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
