@@ -1,5 +1,4 @@
 """State module for managing Buckets."""
-import copy
 from dataclasses import field
 from dataclasses import make_dataclass
 from typing import Any
@@ -339,7 +338,7 @@ async def present(
             return result
 
         # if resource_id is provided explicitly or by ESM, we want update
-        result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
+        result["old_state"] = old_get_ret["ret"]
     elif not hub.OPT.idem.get("get_resource_only_with_resource_id", False):
         # attempt to discover existing resource which is not tracked by idem
         resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
@@ -367,7 +366,7 @@ async def present(
                     RESOURCE_TYPE_FULL, resource_id
                 )
             )
-            result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
+            result["old_state"] = old_get_ret["ret"]
 
     old = result["old_state"]
 
@@ -402,7 +401,7 @@ async def present(
     plan_state = {k: v for (k, v) in plan_state.items() if v is not None}
 
     if old:
-        result["new_state"] = copy.deepcopy(old)
+        result["new_state"] = old
 
         changes = hub.tool.gcp.utils.compare_states(
             old, plan_state, RESOURCE_TYPE_SIMPLE
