@@ -1,3 +1,4 @@
+import copy
 from typing import Any
 from typing import Dict
 from typing import List
@@ -60,85 +61,77 @@ async def update_network_interfaces(
         new_network_interface = changed_interface_value.get("new")
         # According to documentation, only one access config per instance is supported.
         existing_access_configs = existing_network_interface.get("access_configs", [])
-        desired_access_configs = new_network_interface.get("access_configs", [])
+        # None or [] values should be differentiated
+        desired_access_configs = new_network_interface.get("access_configs")
 
-        existing_ac = next(iter(existing_access_configs), None)
-        desired_ac = next(iter(desired_access_configs), None)
-
-        if not existing_ac and not desired_ac:
-            continue
-
-        elif existing_ac and not desired_ac:
-            op_ret = await hub.exec.gcp_api.client.compute.instance.deleteAccessConfig(
-                ctx,
-                resource_id=current_instance.get("resource_id"),
-                access_config=existing_ac.get("name"),
-                network_interface=new_network_interface.get("name"),
+        if desired_access_configs is None:
+            access_config_changes = {}
+        else:
+            access_config_changes = hub.tool.gcp.utils.compare_states(
+                {"network_interfaces": [{"access_configs": existing_access_configs}]},
+                {"network_interfaces": [{"access_configs": desired_access_configs}]},
+                "compute.instance",
             )
 
-            r = await hub.tool.gcp.operation_utils.await_operation_completion(
-                ctx, op_ret, "compute.instance", "compute.zone_operation"
+        if access_config_changes:
+            access_config_result = (
+                await hub.tool.gcp.compute.instance.update_access_configs(
+                    ctx,
+                    existing_access_configs,
+                    desired_access_configs,
+                    current_instance.get("resource_id"),
+                    changed_interface_name,
+                )
             )
-            if not r["result"]:
-                result["comment"] += r["comment"]
-                return result
-
-        elif desired_ac and not existing_ac:
-            op_ret = await hub.exec.gcp_api.client.compute.instance.addAccessConfig(
-                ctx,
-                resource_id=current_instance.get("resource_id"),
-                network_interface=new_network_interface.get("name"),
-                body=desired_ac,
-            )
-
-            r = await hub.tool.gcp.operation_utils.await_operation_completion(
-                ctx, op_ret, "compute.instance", "compute.zone_operation"
-            )
-            if not r["result"]:
-                result["comment"] += r["comment"]
-                return result
-
-        # existing_ac and desired_ac
-        elif next(
-            (
-                key
-                for key in desired_ac.keys()
-                if desired_ac.get(key) != existing_ac.get(key)
-            ),
-            None,
-        ):
-            op_ret = await hub.exec.gcp_api.client.compute.instance.updateAccessConfig(
-                ctx,
-                resource_id=current_instance.get("resource_id"),
-                network_interface=new_network_interface.get("name"),
-                body=desired_ac,
-            )
-
-            r = await hub.tool.gcp.operation_utils.await_operation_completion(
-                ctx, op_ret, "compute.instance", "compute.zone_operation"
-            )
-            if not r["result"]:
-                result["comment"] += r["comment"]
+            if not access_config_result["result"]:
+                result["result"] = False
+                result["comment"] += access_config_result["comment"]
                 return result
 
         # Network interface update
         # Cannot update access config through network interface update function - must be a separate call
-        body = hub.tool.gcp.utils.create_dict_body_on_top_of_old(
+        new_network_interface = hub.tool.gcp.utils.create_dict_body_on_top_of_old(
             ctx, existing_network_interface, new_network_interface
         )
 
         # We want to exclude access configs from update nic operation because it is not supported and
         # it is handled separately.
-        body.pop("access_configs", None)
+        new_network_interface.pop("access_configs", None)
+        existing_network_interface = copy.copy(existing_network_interface)
         existing_network_interface.pop("access_configs", None)
 
-        if body != existing_network_interface:
+        changes = hub.tool.gcp.utils.compare_states(
+            {"network_interfaces": [existing_network_interface]},
+            {"network_interfaces": [new_network_interface]},
+            "compute.instance",
+            additional_exclude_paths=["network_interfaces[].access_configs"],
+        )
+
+        if changes:
+            if access_config_changes:
+                get_ret = await hub.exec.gcp.compute.instance.get(
+                    ctx, resource_id=current_instance.get("resource_id")
+                )
+                if not get_ret["result"] or not get_ret["ret"]:
+                    result["result"] = False
+                    result["comment"] += get_ret["comment"]
+                    return result
+                updated_network_interfaces = get_ret["ret"].get("network_interfaces")
+                new_fingerprint = next(
+                    (
+                        updated_interface.get("fingerprint")
+                        for updated_interface in updated_network_interfaces
+                        if updated_interface.get("name") == changed_interface_name
+                    ),
+                    None,
+                )
+                new_network_interface["fingerprint"] = new_fingerprint
             op_ret = (
                 await hub.exec.gcp_api.client.compute.instance.updateNetworkInterface(
                     ctx,
                     resource_id=current_instance.get("resource_id"),
-                    network_interface=existing_network_interface.get("name"),
-                    body=body,
+                    network_interface=changed_interface_name,
+                    body=new_network_interface,
                 )
             )
 
@@ -146,6 +139,7 @@ async def update_network_interfaces(
                 ctx, op_ret, "compute.instance", "compute.zone_operation"
             )
             if not ret["result"]:
+                result["result"] = False
                 result["comment"] += ret["comment"]
                 return result
 
@@ -153,6 +147,78 @@ async def update_network_interfaces(
     return result
 
 
+async def update_access_configs(
+    hub,
+    ctx,
+    existing_access_configs,
+    desired_access_configs,
+    instance_resource_id,
+    network_interface_name,
+) -> Dict[str, Any]:
+    result = {"result": True, "comment": []}
+
+    # it could still be [] and then desired_ac would be None
+    if desired_access_configs is None:
+        return result
+
+    existing_ac = next(iter(existing_access_configs), None)
+    desired_ac = next(iter(desired_access_configs), None)
+
+    if not existing_ac and not desired_ac:
+        return result
+
+    if existing_ac and not desired_ac:
+        op_ret = await hub.exec.gcp_api.client.compute.instance.deleteAccessConfig(
+            ctx,
+            resource_id=instance_resource_id,
+            access_config=existing_ac.get("name"),
+            network_interface=network_interface_name,
+        )
+
+        r = await hub.tool.gcp.operation_utils.await_operation_completion(
+            ctx, op_ret, "compute.instance", "compute.zone_operation"
+        )
+        if not r["result"]:
+            result["result"] = False
+            result["comment"] += r["comment"]
+
+        return result
+
+    if desired_ac and not existing_ac:
+        op_ret = await hub.exec.gcp_api.client.compute.instance.addAccessConfig(
+            ctx,
+            resource_id=instance_resource_id,
+            network_interface=network_interface_name,
+            body=desired_ac,
+        )
+
+        r = await hub.tool.gcp.operation_utils.await_operation_completion(
+            ctx, op_ret, "compute.instance", "compute.zone_operation"
+        )
+        if not r["result"]:
+            result["result"] = False
+            result["comment"] += r["comment"]
+
+        return result
+
+    # existing_ac and desired_ac
+    op_ret = await hub.exec.gcp_api.client.compute.instance.updateAccessConfig(
+        ctx,
+        resource_id=instance_resource_id,
+        network_interface=network_interface_name,
+        body=desired_ac,
+    )
+
+    r = await hub.tool.gcp.operation_utils.await_operation_completion(
+        ctx, op_ret, "compute.instance", "compute.zone_operation"
+    )
+    if not r["result"]:
+        result["result"] = False
+        result["comment"] += r["comment"]
+
+    return result
+
+
 async def update_shielded_instance_config(
     hub,
     ctx,
