@@ -19,7 +19,10 @@ async def execute(hub, execution_context: ExecutionContext) -> Dict[str, Any]:
             operator_name
         )
         if await operator.should_operate(execution_context):
-            await operator.operate(execution_context)
+            try:
+                await operator.operate(execution_context)
+            except ValueError as e:
+                return {"result": False, "ret": None, "comment": [str(e)]}
 
     execution_context.response = await execution_context.method(
         **execution_context.method_params
