@@ -160,8 +160,10 @@ class ContractMod(LoadedMod):
         )
 
         # TODO: Fix projection required or not
-        if self._method_name in {"create"} and not self._resource_type.startswith(
-            "cloudkms"
+        if (
+            self._method_name in {"create"}
+            and not self._resource_type.startswith("cloudkms")
+            and not self._resource_type.startswith("iam")
         ):
             raw_params["projection"] = "full"
 
