@@ -246,9 +246,10 @@ def get_elements_from_resource_id(hub, resource_type: str, resource_id: str) ->
             result = r
 
     if not result:
-        msg = f"Resource ID {resource_id} matches no resource paths of {resource_type}"
-        hub.log.warning(msg)
-        return {}
+        comment = hub.tool.gcp.comment_utils.ill_formed_resource_id_comment(
+            resource_type, resource_id, resource_paths
+        )
+        raise ValueError(comment)
 
     return result
 
@@ -261,11 +262,6 @@ def get_elements_from_resource_id_and_path(
     result = {}
 
     if len(act) < len(src):
-        hub.log.warning(
-            hub.tool.gcp.comment_utils.ill_formed_resource_id_comment(
-                resource_type, resource_id, "insufficient number of segments."
-            )
-        )
         return {}
 
     idx = -1
@@ -275,11 +271,6 @@ def get_elements_from_resource_id_and_path(
             key = s[1:-1]
             result[key] = val
         elif val != s:
-            hub.log.warning(
-                hub.tool.gcp.comment_utils.ill_formed_resource_id_comment(
-                    resource_type, resource_id, "segment names do not match."
-                )
-            )
             return {}
         idx -= 1
 
@@ -308,7 +299,9 @@ def parse_link_to_resource_id_and_path(
     return result
 
 
-def parse_link_to_resource_id(hub, link, resource_type: str) -> str:
+def parse_link_to_resource_id(
+    hub, link, resource_type: str, log_warnings: bool = True
+) -> str:
     resource_paths = hub.tool.gcp.resource_prop_utils.get_resource_paths(resource_type)
     result = None
     for path in resource_paths:
@@ -323,8 +316,9 @@ def parse_link_to_resource_id(hub, link, resource_type: str) -> str:
             result = r
 
     if not result:
-        msg = f"Link {link} matches no resource paths of {resource_type}"
-        hub.log.warning(msg)
+        if log_warnings:
+            msg = f"Link {link} matches no resource paths of {resource_type}"
+            hub.log.warning(msg)
         return None
 
     return result
@@ -337,7 +331,7 @@ def construct_resource_id(hub, resource_type: str, input_props: Dict[str, Any])
         try:
             if (
                 hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
-                    name, resource_type
+                    name, resource_type, log_warnings=False
                 )
                 is not None
             ):
